pub struct CensusRequest { /* private fields */ }Trait Implementations
Sourceimpl Clone for CensusRequest
impl Clone for CensusRequest
Sourcefn clone(&self) -> CensusRequest
fn clone(&self) -> CensusRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CensusRequest
impl Debug for CensusRequest
Sourceimpl IntoFuture for CensusRequest
impl IntoFuture for CensusRequest
Sourcetype Output = Result<CensusResponse, AuraxisError>
type Output = Result<CensusResponse, AuraxisError>
The output that the future will produce on completion.
Sourcetype IntoFuture = impl Future<Output = <CensusRequest as IntoFuture>::Output>
type IntoFuture = impl Future<Output = <CensusRequest as IntoFuture>::Output>
Which kind of future are we turning this into?
Sourcefn into_future(self) -> Self::IntoFuture
fn into_future(self) -> Self::IntoFuture
Creates a future from a value. Read more